@@ -29,6 +29,8 @@
 #' @param eq.x.rhs \code{character} this string will be used as replacement
 #'   for \code{"x"} in the model equation when generating the label before
 #'   parsing it.
+#' @param label.x,label.y \code{numeric} Coordinates to be used in output. If
+#'   too short they will be recycled.
 #'
 #' @note For backward compatibility a logical is accepted as argument for
 #'   \code{eq.with.lhs}, giving the same output than the current default
@@ -59,6 +61,8 @@
 #'   \item{rr.label}{\eqn{R^2} of the fitted model as a character string to be parsed}
 #'   \item{adj.rr.label}{Adjusted \eqn{R^2} of the fitted model as a character string
 #'   to be parsed}
+#'   \item{AIC.label}{AIC for the fitted model.}
+#'   \item{BIC.label}{BIC for the fitted model.}
 #'   \item{hjust}{Set to zero to override the default of the "text" geom.}}
 #'
 #' @examples
@@ -82,6 +86,7 @@ stat_poly_eq <- function(mapping = NULL, data = NULL, geom = "text",
                          formula = NULL,
                          eq.with.lhs = "italic(y)~`=`~",
                          eq.x.rhs = "~italic(x)",
+                         label.x = NULL, label.y = NULL,
                          position = "identity",
                          na.rm = FALSE, show.legend = FALSE,
                          inherit.aes = TRUE, ...) {
@@ -91,6 +96,8 @@ stat_poly_eq <- function(mapping = NULL, data = NULL, geom = "text",
     params = list(formula = formula,
                   eq.with.lhs = eq.with.lhs,
                   eq.x.rhs = eq.x.rhs,
+                  label.x = label.x,
+                  label.y = label.y,
                   na.rm = na.rm,
                   ...)
   )
@@ -107,7 +114,28 @@ poly_eq_compute_group_fun <- function(data,
                                      scales,
                                      formula,
                                      eq.with.lhs,
-                                     eq.x.rhs) {
+                                     eq.x.rhs,
+                                     label.x,
+                                     label.y) {
+  group.idx <- abs(data$group[1])
+  if (length(label.x) == 0) { # TRUE also for NULL
+    label.x <- min(data$x)
+  } else {
+    if (length(label.x < group.idx)) {
+      # we simulate recycling
+      label.x <- rep(label.x, length.out = group.idx)
+    }
+    label.x <- label.x[group.idx]
+  }
+  if (length(label.y) == 0) { # TRUE also for NULL
+    label.y <- max(data$y) - 0.1 * diff(range(data$y))
+  } else {
+    if (length(label.y < group.idx)) {
+      # we simulate recycling
+      label.y <- rep(label.y, length.out = group.idx)
+    }
+    label.y <- label.y[group.idx]
+  }
   mf <- stats::lm(formula, data)
   coefs <- stats::coef(mf)
   formula.rhs.chr <- as.character(formula)[3]
@@ -115,8 +143,11 @@ poly_eq_compute_group_fun <- function(data,
     coefs <- c(0, coefs)
   }
   rr <- summary(mf)$r.squared
+  AIC <- AIC(mf)
+  BIC <- BIC(mf)
   adj.rr <- summary(mf)$adj.r.squared
   eq.char <- as.character(signif(polynom::as.polynomial(coefs), 3))
+  eq.char <- gsub("e([+-]?[0-9]*)", "%*%10^\\1", eq.char)
   if (is.character(eq.with.lhs)) {
     lhs <- eq.with.lhs
     eq.with.lhs <- TRUE
@@ -128,12 +159,16 @@ poly_eq_compute_group_fun <- function(data,
   }
   rr.char <- format(rr, digits = 2)
   adj.rr.char <- format(adj.rr, digits = 2)
-  data.frame(x = min(data$x),
-             y = max(data$y) - 0.1 * diff(range(data$y)),
+  AIC.char <- sprintf("%.4g", AIC)
+  BIC.char <- sprintf("%.4g", BIC)
+  data.frame(x = label.x,
+             y = label.y,
              eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
              rr.label = paste("italic(R)^2", rr.char, sep = "~`=`~"),
              adj.rr.label = paste("italic(R)[adj]^2",
                                   adj.rr.char, sep = "~`=`~"),
+             AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
+             BIC.label = paste("BIC", BIC.char, sep = "~`=`~"),
              hjust = 0)
 }
 
